summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorBram Moolenaar <Bram@vim.org>2006-04-18 21:55:01 +0000
committerBram Moolenaar <Bram@vim.org>2006-04-18 21:55:01 +0000
commitc1e37901fc8486c9960d7290e521ba51e292e94b (patch)
tree5367e8f83d9d313dd73c0499fd310f57df5e605f /src
parenta93fa7ee7856b54d3778e613c7b7e4b76aaeb2af (diff)
updated for version 7.0e02v7.0e02
Diffstat (limited to 'src')
-rw-r--r--src/edit.c83
-rw-r--r--src/fileio.c2
-rw-r--r--src/getchar.c37
-rw-r--r--src/gui.h43
-rw-r--r--src/gui_gtk.c38
-rw-r--r--src/gui_gtk_x11.c5
-rw-r--r--src/if_cscope.c6
-rw-r--r--src/netbeans.c2
-rw-r--r--src/option.c4
-rw-r--r--src/po/ja.po111
-rw-r--r--src/po/ja.sjis.po111
-rw-r--r--src/po/sv.po572
-rw-r--r--src/po/zh_CN.UTF-8.po3998
-rw-r--r--src/po/zh_CN.cp936.po3996
-rw-r--r--src/po/zh_CN.po3996
-rw-r--r--src/syntax.c14
-rw-r--r--src/tag.c7
-rw-r--r--src/version.h6
-rw-r--r--src/vim.h2
19 files changed, 8941 insertions, 4092 deletions
diff --git a/src/fileio.c b/src/fileio.c
index 1c4cab8291..34a53e63e5 100644
--- a/src/fileio.c
+++ b/src/fileio.c
@@ -1113,7 +1113,7 @@ retry:
size = 0x7ff0L - linerest; /* limit buffer to 32K */
#endif
- for ( ; size >= 10; size = (long_u)size >> 1)
+ for ( ; size >= 10; size = (long)((long_u)size >> 1))
{
if ((new_buffer = lalloc((long_u)(size + linerest + 1),
FALSE)) != NULL)
diff --git a/src/getchar.c b/src/getchar.c
index 3d851653db..0ba97b4065 100644
--- a/src/getchar.c
+++ b/src/getchar.c
@@ -128,6 +128,9 @@ static int vgetorpeek __ARGS((int));
static void map_free __ARGS((mapblock_T **));
static void validate_maphash __ARGS((void));
static void showmap __ARGS((mapblock_T *mp, int local));
+#ifdef FEAT_EVAL
+static char_u *eval_map_expr __ARGS((char_u *str));
+#endif
/*
* Free and clear a buffer.
@@ -2328,7 +2331,7 @@ vgetorpeek(advance)
if (tabuf.typebuf_valid)
{
vgetc_busy = 0;
- s = eval_to_string(mp->m_str, NULL, FALSE);
+ s = eval_map_expr(mp->m_str);
vgetc_busy = save_vgetc_busy;
}
else
@@ -4251,7 +4254,7 @@ check_abbr(c, ptr, col, mincol)
}
#ifdef FEAT_EVAL
if (mp->m_expr)
- s = eval_to_string(mp->m_str, NULL, FALSE);
+ s = eval_map_expr(mp->m_str);
else
#endif
s = mp->m_str;
@@ -4281,6 +4284,36 @@ check_abbr(c, ptr, col, mincol)
return FALSE;
}
+#ifdef FEAT_EVAL
+/*
+ * Evaluate the RHS of a mapping or abbreviations and take care of escaping
+ * special characters.
+ */
+ static char_u *
+eval_map_expr(str)
+ char_u *str;
+{
+ char_u *res;
+ char_u *s;
+ int len;
+
+ s = eval_to_string(str, NULL, FALSE);
+ if (s == NULL)
+ return NULL;
+
+ /* Need a buffer to hold up to three times as much. */
+ len = (int)STRLEN(s);
+ res = alloc((unsigned)(len * 3) + 1);
+ if (res != NULL)
+ {
+ STRCPY(res, s);
+ (void)fix_input_buffer(res, len, TRUE);
+ }
+ vim_free(s);
+ return res;
+}
+#endif
+
/*
* Write map commands for the current mappings to an .exrc file.
* Return FAIL on error, OK otherwise.
diff --git a/src/gui.h b/src/gui.h
index f221c2981f..36156f9ddc 100644
--- a/src/gui.h
+++ b/src/gui.h
@@ -504,3 +504,46 @@ typedef enum
# define FRD_WHOLE_WORD 0x08 /* match whole word only */
# define FRD_MATCH_CASE 0x10 /* match case */
#endif
+
+#ifdef HAVE_GTK2
+/*
+ * Convenience macros to convert from 'encoding' to 'termencoding' and
+ * vice versa. If no conversion is necessary the passed-in pointer is
+ * returned as is, without allocating any memory. Thus additional _FREE()
+ * macros are provided. The _FREE() macros also set the pointer to NULL,
+ * in order to avoid bugs due to illegal memory access only happening if
+ * 'encoding' != utf-8...
+ *
+ * Defining these macros as pure expressions looks a bit tricky but
+ * avoids depending on the context of the macro expansion. One of the
+ * rare occasions where the comma operator comes in handy :)
+ *
+ * Note: Do NOT keep the result around when handling control back to
+ * the main Vim! The user could change 'encoding' at any time.
+ */
+# define CONVERT_TO_UTF8(String) \
+ ((output_conv.vc_type == CONV_NONE || (String) == NULL) \
+ ? (String) \
+ : string_convert(&output_conv, (String), NULL))
+
+# define CONVERT_TO_UTF8_FREE(String) \
+ ((String) = ((output_conv.vc_type == CONV_NONE) \
+ ? (char_u *)NULL \
+ : (vim_free(String), (char_u *)NULL)))
+
+# define CONVERT_FROM_UTF8(String) \
+ ((input_conv.vc_type == CONV_NONE || (String) == NULL) \
+ ? (String) \
+ : string_convert(&input_conv, (String), NULL))
+
+# define CONVERT_FROM_UTF8_FREE(String) \
+ ((String) = ((input_conv.vc_type == CONV_NONE) \
+ ? (char_u *)NULL \
+ : (vim_free(String), (char_u *)NULL)))
+
+#else
+# define CONVERT_TO_UTF8(String) (String)
+# define CONVERT_TO_UTF8_FREE(String) ((String) = (char_u *)NULL)
+# define CONVERT_FROM_UTF8(String) (String)
+# define CONVERT_FROM_UTF8_FREE(String) ((String) = (char_u *)NULL)
+#endif /* HAVE_GTK2 */
diff --git a/src/gui_gtk.c b/src/gui_gtk.c
index a1c43751b4..d9477d5b67 100644
--- a/src/gui_gtk.c
+++ b/src/gui_gtk.c
@@ -131,44 +131,6 @@ typedef int GtkWidget;
# define CancelData int
#endif
-#ifdef HAVE_GTK2
-/*
- * Convenience macros to convert from 'encoding' to 'termencoding' and
- * vice versa. If no conversion is necessary the passed-in pointer is
- * returned as is, without allocating any memory. Thus additional _FREE()
- * macros are provided. The _FREE() macros also set the pointer to NULL,
- * in order to avoid bugs due to illegal memory access only happening if
- * 'encoding' != utf-8...
- *
- * Defining these macros as pure expressions looks a bit tricky but
- * avoids depending on the context of the macro expansion. One of the
- * rare occasions where the comma operator comes in handy :)
- *
- * Note: Do NOT keep the result around when handling control back to
- * the main Vim! The user could change 'encoding' at any time.
- */
-# define CONVERT_TO_UTF8(String) \
- ((output_conv.vc_type == CONV_NONE || (String) == NULL) \
- ? (String) \
- : string_convert(&output_conv, (String), NULL))
-
-# define CONVERT_TO_UTF8_FREE(String) \
- ((String) = ((output_conv.vc_type == CONV_NONE) \
- ? (char_u *)NULL \
- : (vim_free(String), (char_u *)NULL)))
-
-# define CONVERT_FROM_UTF8(String) \
- ((input_conv.vc_type == CONV_NONE || (String) == NULL) \
- ? (String) \
- : string_convert(&input_conv, (String), NULL))
-
-# define CONVERT_FROM_UTF8_FREE(String) \
- ((String) = ((input_conv.vc_type == CONV_NONE) \
- ? (char_u *)NULL \
- : (vim_free(String), (char_u *)NULL)))
-
-#endif /* HAVE_GTK2 */
-
static void entry_activate_cb(GtkWidget *widget, gpointer data);
static void entry_changed_cb(GtkWidget *entry, GtkWidget *dialog);
static void find_replace_cb(GtkWidget *widget, gpointer data);
diff --git a/src/gui_gtk_x11.c b/src/gui_gtk_x11.c
index 9eb85ce144..23318bb7a3 100644
--- a/src/gui_gtk_x11.c
+++ b/src/gui_gtk_x11.c
@@ -3293,6 +3293,7 @@ gui_mch_update_tabline(void)
tabpage_T *tp;
int nr = 0;
int curtabidx = 0;
+ char_u *labeltext;
if (gui.tabline == NULL)
return;
@@ -3320,8 +3321,10 @@ gui_mch_update_tabline(void)
}
get_tabline_label(tp);
+ labeltext = CONVERT_TO_UTF8(NameBuff);
gtk_notebook_set_tab_label_text(GTK_NOTEBOOK(gui.tabline), page,
- (const gchar *)NameBuff);
+ (const gchar *)labeltext);
+ CONVERT_TO_UTF8_FREE(labeltext);
}
/* Remove any old labels. */
diff --git a/src/if_cscope.c b/src/if_cscope.c
index 81c7a6a1fd..1eb3616e75 100644
--- a/src/if_cscope.c
+++ b/src/if_cscope.c
@@ -723,7 +723,7 @@ cs_create_connection(i)
char *prog, *cmd, *ppath = NULL;
#ifndef UNIX
int in_save, out_save, err_save;
- long ph;
+ long_i ph;
# ifdef FEAT_GUI
HWND activewnd = NULL;
HWND consolewnd = NULL;
@@ -881,9 +881,9 @@ err_closing:
/* May be use &shell, &shellquote etc */
# ifdef __BORLANDC__
/* BCC 5.5 uses a different function name for spawnlp */
- ph = (long)spawnlp(P_NOWAIT, prog, cmd, NULL);
+ ph = (long_i)spawnlp(P_NOWAIT, prog, cmd, NULL);
# else
- ph = (long)_spawnlp(_P_NOWAIT, prog, cmd, NULL);
+ ph = (long_i)_spawnlp(_P_NOWAIT, prog, cmd, NULL);
# endif
vim_free(prog);
vim_free(cmd);
diff --git a/src/netbeans.c b/src/netbeans.c
index 8928342d21..731b98b24b 100644
--- a/src/netbeans.c
+++ b/src/netbeans.c
@@ -169,7 +169,7 @@ netbeans_gtk_connect(void)
* Tell gdk we are interested in being called when there
* is input on the editor connection socket
*/
- inputHandler = gdk_input_add(sd, (GdkInputCondition)
+ inputHandler = gdk_input_add((gint)sd, (GdkInputCondition)
((int)GDK_INPUT_READ + (int)GDK_INPUT_EXCEPTION),
messageFromNetbeans, NULL);
}
diff --git a/src/option.c b/src/option.c
index cb456bf7e5..29ab1efe8d 100644
--- a/src/option.c
+++ b/src/option.c
@@ -3496,7 +3496,7 @@ set_init_2()
* 'scroll' defaults to half the window height. Note that this default is
* wrong when the window height changes.
*/
- set_number_default("scroll", (long_u)Rows >> 1);
+ set_number_default("scroll", (long)((long_u)Rows >> 1));
idx = findoption((char_u *)"scroll");
if (!(options[idx].flags & P_WAS_SET))
set_option_default(idx, OPT_LOCAL, p_cp);
@@ -3643,12 +3643,14 @@ set_init_3()
if ( fnamecmp(p, "sh") == 0
|| fnamecmp(p, "ksh") == 0
|| fnamecmp(p, "zsh") == 0
+ || fnamecmp(p, "zsh-beta") == 0
|| fnamecmp(p, "bash") == 0
# ifdef WIN3264
|| fnamecmp(p, "cmd") == 0
|| fnamecmp(p, "sh.exe") == 0
|| fnamecmp(p, "ksh.exe") == 0
|| fnamecmp(p, "zsh.exe") == 0
+ || fnamecmp(p, "zsh-beta.exe") == 0
|| fnamecmp(p, "bash.exe") == 0
|| fnamecmp(p, "cmd.exe") == 0
# endif
diff --git a/src/po/ja.po b/src/po/ja.po
index db6bedd4bc..67d877d47f 100644
--- a/src/po/ja.po
+++ b/src/po/ja.po
@@ -4,13 +4,13 @@
# Do ":help credits" in Vim to see a list of people who contributed.
#
# MURAOKA Taro <koron@tka.att.ne.jp>, 2001-6.
-# Last Change: 28-Mar-2006.
+# Last Change: 18-Apr-2006.
#
msgid ""
msgstr ""
"Project-Id-Version: Vim 7.0\n"
-"POT-Creation-Date: 2006-03-28 20:12+0900\n"
-"PO-Revision-Date: 2006-03-28 21:10+0900\n"
+"POT-Creation-Date: 2006-04-18 11:00+0900\n"
+"PO-Revision-Date: 2006-04-18 11:30+0900\n"
"Last-Translator: MURAOKA Taro <koron@tka.att.ne.jp>\n"
"Language-Team: MURAOKA Taro <koron@tka.att.ne.jp>\n"
"MIME-Version: 1.0\n"
@@ -204,6 +204,9 @@ msgstr "E102: バッファ \"%s\" がみつかりません"
msgid "E103: Buffer \"%s\" is not in diff mode"
msgstr "E103: バッファ \"%s\" は差分モードではありません"
+msgid "E787: Buffer changed unexpectedly"
+msgstr "E787: 予期せずバッファが変更変更されました"
+
msgid "E104: Escape not allowed in digraph"
msgstr "E104: 合字にEscapeは使用できません"
@@ -217,8 +220,8 @@ msgid " Keyword completion (^N^P)"
msgstr " キーワード補完 (^N^P)"
#. ctrl_x_mode == 0, ^P/^N compl.
-msgid " ^X mode (^]^D^E^F^I^K^L^N^O^P^S^U^V^Y)"
-msgstr " ^X モード (^]^D^E^F^I^K^L^N^O^P^S^U^V^Y)"
+msgid " ^X mode (^]^D^E^F^I^K^L^N^O^Ps^U^V^Y)"
+msgstr " ^X モード (^]^D^E^F^I^K^L^N^O^Ps^U^V^Y)"
msgid " Whole line completion (^L^N^P)"
msgstr " 行(全体)補完 (^L^N^P)"
@@ -250,8 +253,8 @@ msgstr " ユーザ定義補完 (^U^N^P)"
msgid " Omni completion (^O^N^P)"
msgstr " オムニ補完 (^O^N^P)"
-msgid " Spelling suggestion (^S^N^P)"
-msgstr " 綴り修正候補 (^S^N^P)"
+msgid " Spelling suggestion (s^N^P)"
+msgstr " 綴り修正候補 (s^N^P)"
msgid " Keyword Local completion (^N^P)"
msgstr " 局所キーワード補完 (^N^P)"
@@ -486,6 +489,22 @@ msgstr "E723: 辞書型の最後に '}' がありません: %s"
msgid "E724: variable nested too deep for displaying"
msgstr "E724: 表示するには変数の入れ子が深過ぎます"
+#, c-format
+msgid "E117: Unknown function: %s"
+msgstr "E117: 未知の関数です: %s"
+
+#, c-format
+msgid "E119: Not enough arguments for function: %s"
+msgstr "E119: 関数の引数が少な過ぎます: %s"
+
+#, c-format
+msgid "E120: Using <SID> not in a script context: %s"
+msgstr "E120: スクリプト以外で<SID>が使われました: %s"
+
+#, c-format
+msgid "E725: Calling dict function without Dictionary: %s"
+msgstr "E725: 辞書用関数が呼ばれましたが辞書がありません: %s"
+
msgid "E699: Too many arguments"
msgstr "E699: が多過ぎます"
@@ -522,8 +541,8 @@ msgstr ""
msgid "called inputrestore() more often than inputsave()"
msgstr "inputrestore() が inputsave() よりも多く呼ばれました"
-msgid "E745: Range not allowed"
-msgstr "E745: 範囲指定は許可されていません"
+msgid "E786: Range not allowed"
+msgstr "E786: 範囲指定は許可されていません"
msgid "E701: Invalid type for len()"
msgstr "E701: len() には無効な型です"
@@ -1380,6 +1399,9 @@ msgstr "E602: :try のない :endtry です"
msgid "E193: :endfunction not inside a function"
msgstr "E193: 関数の外に :endfunction がありました"
+msgid "E788: Not allowed to edit another buffer now"
+msgstr "E788: 現在は他のバッファを編集することは許されません"
+
msgid "tagname"
msgstr "タグ名"
@@ -2484,12 +2506,33 @@ msgstr "<ウィンドウ %d>"
msgid "no such window"
msgstr "そのようなウィンドウはありません"
+msgid "E265: $_ must be an instance of String"
+msgstr "E265: $_ は文字列のインスタンスでなければなりません"
+
msgid ""
"E266: Sorry, this command is disabled, the Ruby library could not be loaded."
msgstr ""
"E266: このコマンドは無効です,ごめんなさい: "
"Rubyライブラリをロードできませんでした."
+msgid "E267: unexpected return"
+msgstr "E265: 予期せぬ return です"
+
+msgid "E268: unexpected next"
+msgstr "E268: 予期せぬ next です"
+
+msgid "E269: unexpected break"
+msgstr "E269: 予期せぬ break です"
+
+msgid "E270: unexpected redo"
+msgstr "E270: 予期せぬ redo です"
+
+msgid "E271: retry outside of rescue clause"
+msgstr "E271: rescue の外の retry です"
+
+msgid "E272: unhandled exception"
+msgstr "E272: 取り扱われなかった例外があります"
+
#, c-format
msgid "E273: unknown longjmp status %d"
msgstr "E273: 未知のlongjmp状態: %d"
@@ -4184,9 +4227,6 @@ msgstr "ANCHOR_BUF_SIZE が小さ過ぎます."
msgid "I/O ERROR"
msgstr "入出力エラー"
-msgid "...(truncated)"
-msgstr "...(省略)"
-
msgid "Message"
msgstr "メッセージ"
@@ -4621,6 +4661,16 @@ msgstr "E388: 定義をみつけられません"
msgid "E389: Couldn't find pattern"
msgstr "E389: パターンをみつけられません"
+#, c-format
+msgid ""
+"\n"
+"# Last %sSearch Pattern:\n"
+"~"
+msgstr ""
+"\n"
+"# 最後の %s検索パターン:\n"
+"~"
+
msgid "E759: Format error in spell file"
msgstr "E759: スペルファイルの書式エラーです"
@@ -4646,7 +4696,7 @@ msgid "Compressing word tree..."
msgstr "単語ツリーを圧縮しています..."
msgid "E756: Spell checking is not enabled"
-msgstr "E756: すぺくチェックは無効化されています"
+msgstr "E756: スペルチェックは無効化されています"
#, c-format
msgid "Warning: Cannot find word list \"%s.%s.spl\" or \"%s.ascii.spl\""
@@ -4698,6 +4748,22 @@ msgid "FLAG after using flags in %s line %d: %s"
msgstr "%s 内の %d 行目にフラグの二重使用があります: %s"
#, c-format
+msgid ""
+"Defining COMPOUNDFORBIDFLAG after PFX item may give wrong results in %s line "
+"%d"
+msgstr ""
+"%s の %d 行目の PFX 項目の後の COMPOUNDFORBIDFLAG "
+"の定義は誤った結果を生じることがあります"
+
+#, c-format
+msgid ""
+"Defining COMPOUNDPERMITFLAG after PFX item may give wrong results in %s line "
+"%d"
+msgstr ""
+"%s の %d 行目の PFX 項目の後の COMPOUNDPERMITFLAG "
+"の定義は誤った結果を生じることがあります"
+
+#, c-format
msgid "Wrong COMPOUNDWORDMAX value in %s line %d: %s"
msgstr "%s の %d 行目の COMPOUNDWORDMAX の値に誤りがあります: %s"
@@ -4739,10 +4805,6 @@ msgid "Broken condition in %s line %d: %s"
msgstr "%s の %d 行目の 条件は壊れています: %s"
#, c-format
-msgid "Affix flags ignored when PFXPOSTPONE used in %s line %d: %s"
-msgstr "PFXPOSTPONEが指定されたので %s の %d 行目の affix フラグを無視しました: %s"
-
-#, c-format
msgid "Expected REP(SAL) count in %s line %d"
msgstr "%s の %d 行目には REP(SAL) の回数が必要です"
@@ -5299,7 +5361,7 @@ msgstr "E438: u_undo: 行番号が間違っています"
msgid "more line"
msgstr "行 追加しました"
-msgid "行あります"
+msgid "more lines"
msgstr "行 追加しました"
msgid "line less"
@@ -5330,6 +5392,10 @@ msgstr "アンドゥ対象がありません"
msgid "number changes time"
msgstr "番号 変更 時刻"
+#, c-format
+msgid "%ld seconds ago"
+msgstr "%ld 秒経過しています"
+
msgid "E439: undo list corrupt"
msgstr "E439: アンドゥリストが壊れています"
@@ -5636,6 +5702,9 @@ msgstr " 警告: Windows 95/98/Me を検出 "
msgid "type :help windows95<Enter> for info on this"
msgstr " 詳細な情報は :help windows95<Enter> "
+msgid "Already only one window"
+msgstr "既にウィンドウは1つしかありません"
+
msgid "E441: There is no preview window"
msgstr "E441: プレビューウィンドウがありません"
@@ -5648,9 +5717,6 @@ msgstr "E443: 他のウィンドウが分割されている時には順回できません"
msgid "E444: Cannot close last window"
msgstr "E444: 最後のウィンドウを閉じることはできません"
-msgid "Already only one window"
-msgstr "既にウィンドウは1つしかありません"
-
msgid "E445: Other window contains changes"
msgstr "E445: 他のウィンドウには変更があります"
@@ -5680,7 +5746,8 @@ msgid "Edits the selected file(s) with Vim"
msgstr "選択されたファイルをVimで編集する"
msgid "Error creating process: Check if gvim is in your path!"
-msgstr "起動に失敗しました: gvim へのパスが正しく設定されているか確認してください!"
+msgstr ""
+"起動に失敗しました: gvim へのパスが正しく設定されているか確認してください!"
msgid "gvimext.dll error"
msgstr "gvimext.dll エラー"
diff --git a/src/po/ja.sjis.po b/src/po/ja.sjis.po
index f663ea29ff..29592bb3c3 100644
--- a/src/po/ja.sjis.po
+++ b/src/po/ja.sjis.po
@@ -4,13 +4,13 @@
# Do ":help credits" in Vim to see a list of people who contributed.
#
# MURAOKA Taro <koron@tka.att.ne.jp>, 2001-6.
-# Last Change: 28-Mar-2006.
+# Last Change: 18-Apr-2006.
#
msgid ""
msgstr ""
"Project-Id-Version: Vim 7.0\n"
-"POT-Creation-Date: 2006-03-28 20:12+0900\n"
-"PO-Revision-Date: 2006-03-28 21:10+0900\n"
+"POT-Creation-Date: 2006-04-18 11:00+0900\n"
+"PO-Revision-Date: 2006-04-18 11:30+0900\n"
"Last-Translator: MURAOKA Taro <koron@tka.att.ne.jp>\n"
"Language-Team: MURAOKA Taro <koron@tka.att.ne.jp>\n"
"MIME-Version: 1.0\n"
@@ -204,6 +204,9 @@ msgstr "E102: obt@ \"%s\" "
msgid "E103: Buffer \"%s\" is not in diff mode"
msgstr "E103: obt@ \"%s\" [h"
+msgid "E787: Buffer changed unexpectedly"
+msgstr "E787: \\obt@XX"
+
msgid "E104: Escape not allowed in digraph"
msgstr "E104: Escapegp"
@@ -217,8 +220,8 @@ msgid " Keyword completion (^N^P)"
msgstr " L[[h (^N^P)"
#. ctrl_x_mode == 0, ^P/^N compl.
-msgid " ^X mode (^]^D^E^F^I^K^L^N^O^P^S^U^V^Y)"
-msgstr " ^X [h (^]^D^E^F^I^K^L^N^O^P^S^U^V^Y)"
+msgid " ^X mode (^]^D^E^F^I^K^L^N^O^Ps^U^V^Y)"
+msgstr " ^X [h (^]^D^E^F^I^K^L^N^O^Ps^U^V^Y)"
msgid " Whole line completion (^L^N^P)"
msgstr " s(S) (^L^N^P)"
@@ -250,8 +253,8 @@ msgstr " [U` (^U^N^P)"
msgid " Omni completion (^O^N^P)"
msgstr " Ij (^O^N^P)"
-msgid " Spelling suggestion (^S^N^P)"
-msgstr " C (^S^N^P)"
+msgid " Spelling suggestion (s^N^P)"
+msgstr " C (s^N^P)"
msgid " Keyword Local completion (^N^P)"
msgstr " L[[h (^N^P)"
@@ -486,6 +489,22 @@ msgstr "E723: ォ^ '}' : %s"
msgid "E724: variable nested too deep for displaying"
msgstr "E724: \\ヲq["
+#, c-format
+msgid "E117: Unknown function: %s"
+msgstr "E117: m: %s"
+
+#, c-format
+msgid "E119: Not enough arguments for function: %s"
+msgstr "E119: : %s"
+
+#, c-format
+msgid "E120: Using <SID> not in a script context: %s"
+msgstr "E120: XNvgO<SID>g: %s"
+
+#, c-format
+msgid "E725: Calling dict function without Dictionary: %s"
+msgstr "E725: ォpォ: %s"
+
msgid "E699: Too many arguments"
msgstr "E699: "
@@ -522,8 +541,8 @@ msgstr ""
msgid "called inputrestore() more often than inputsave()"
msgstr "inputrestore() inputsave() "
-msgid "E745: Range not allowed"
-msgstr "E745: w"
+msgid "E786: Range not allowed"
+msgstr "E786: w"
msgid "E701: Invalid type for len()"
msgstr "E701: len() ^"
@@ -1380,6 +1399,9 @@ msgstr "E602: :try :endtry "
msgid "E193: :endfunction not inside a function"
msgstr "E193: O :endfunction "
+msgid "E788: Not allowed to edit another buffer now"
+msgstr "E788: obt@W"
+
msgid "tagname"
msgstr "^O"
@@ -2484,12 +2506,33 @@ msgstr "<EBhE %d>"
msgid "no such window"
msgstr "EBhE"
+msgid "E265: $_ must be an instance of String"
+msgstr "E265: $_ CX^X"
+
msgid ""
"E266: Sorry, this command is disabled, the Ruby library could not be loaded."
msgstr ""
"E266: R}h,: "
"RubyCu[h."
+msgid "E267: unexpected return"
+msgstr "E265: \\ return "
+
+msgid "E268: unexpected next"
+msgstr "E268: \\ next "
+
+msgid "E269: unexpected break"
+msgstr "E269: \\ break "
+
+msgid "E270: unexpected redo"
+msgstr "E270: \\ redo "
+
+msgid "E271: retry outside of rescue clause"
+msgstr "E271: rescue O retry "
+
+msgid "E272: unhandled exception"
+msgstr "E272: O"
+
#, c-format
msgid "E273: unknown longjmp status %d"
msgstr "E273: mlongjmp: %d"
@@ -4184,9 +4227,6 @@ msgstr "ANCHOR_BUF_SIZE ."
msgid "I/O ERROR"
msgstr "oG["
-msgid "...(truncated)"
-msgstr "...()"
-
msgid "Message"
msgstr "bZ[W"
@@ -4621,6 +4661,16 @@ msgstr "E388: `"
msgid "E389: Couldn't find pattern"
msgstr "E389: p^["
+#, c-format
+msgid ""
+"\n"
+"# Last %sSearch Pattern:\n"
+"~"
+msgstr ""
+"\n"
+"# %sp^[:\n"
+"~"
+
msgid "E759: Format error in spell file"
msgstr "E759: Xyt@CョG["
@@ -4646,7 +4696,7 @@ msgid "Compressing word tree..."
msgstr "Pc[k..."
msgid "E756: Spell checking is not enabled"
-msgstr "E756: `FbN"
+msgstr "E756: Xy`FbN"
#, c-format
msgid "Warning: Cannot find word list \"%s.%s.spl\" or \"%s.ascii.spl\""
@@ -4698,6 +4748,22 @@ msgid "FLAG after using flags in %s line %d: %s"
msgstr "%s %d stOdgp: %s"
#, c-format
+msgid ""
+"Defining COMPOUNDFORBIDFLAG after PFX item may give wrong results in %s line "
+"%d"
+msgstr ""
+"%s %d s PFX COMPOUNDFORBIDFLAG "
+"`"
+
+#, c-format
+msgid ""
+"Defining COMPOUNDPERMITFLAG after PFX item may give wrong results in %s line "
+"%d"
+msgstr ""
+"%s %d s PFX COMPOUNDPERMITFLAG "
+"`"
+
+#, c-format
msgid "Wrong COMPOUNDWORDMAX value in %s line %d: %s"
msgstr "%s %d s COMPOUNDWORDMAX l: %s"
@@ -4739,10 +4805,6 @@ msgid "Broken condition in %s line %d: %s"
msgstr "%s %d s : %s"
#, c-format
-msgid "Affix flags ignored when PFXPOSTPONE used in %s line %d: %s"
-msgstr "PFXPOSTPONEw %s %d s affix tO: %s"
-
-#, c-format
msgid "Expected REP(SAL) count in %s line %d"
msgstr "%s %d s REP(SAL) Kv"
@@ -5299,7 +5361,7 @@ msgstr "E438: u_undo: s"
msgid "more line"
msgstr "s "
-msgid "s"
+msgid "more lines"
msgstr "s "
msgid "line less"
@@ -5330,6 +5392,10 @@ msgstr "AhD"
msgid "number changes time"
msgstr " X "
+#, c-format
+msgid "%ld seconds ago"
+msgstr "%ld bo"
+
msgid "E439: undo list corrupt"
msgstr "E439: AhDXg"
@@ -5636,6 +5702,9 @@ msgstr " x: Windows 95/98/Me o "
msgid "type :help windows95<Enter> for info on this"
msgstr " :help windows95<Enter> "
+msgid "Already only one window"
+msgstr "EBhE1"
+
msgid "E441: There is no preview window"
msgstr "E441: vr[EBhE"
@@ -5648,9 +5717,6 @@ msgstr "E443: EBhE"
msgid "E444: Cannot close last window"
msgstr "E444: EBhE"
-msgid "Already only one window"
-msgstr "EBhE1"
-
msgid "E445: Other window contains changes"
msgstr "E445: EBhEX"
diff --git a/src/edit.c b/src/edit.c
index c6287e056e..ed416f30a1 100644
--- a/src/edit.c
+++ b/src/edit.c
@@ -709,15 +709,20 @@ edit(cmdchar, startln, count)
{
/* BS: Delete one character from "compl_leader". */
if ((c == K_BS || c == Ctrl_H)
- && curwin->w_cursor.col > compl_col && ins_compl_bs())
+ && curwin->w_cursor.col > compl_col
+ && (c = ins_compl_bs()) == NUL)
continue;
/* When no match was selected or it was edited. */
if (!compl_used_match)
{
/* CTRL-L: Add one character from the current match to
- * "compl_leader". */
- if (c == Ctrl_L)
+ * "compl_leader". Except when at the original match and
+ * there is nothing to add, CTRL-L works like CTRL-P then. */
+ if (c == Ctrl_L
+ && (ctrl_x_mode != CTRL_X_WHOLE_LINE
+ || STRLEN(compl_shown_match->cp_str)
+ > curwin->w_cursor.col - compl_col))
{
ins_compl_addfrommatch();
continue;
@@ -2943,7 +2948,8 @@ ins_compl_active()
/*
* Delete one character before the cursor and show the subset of the matches
* that match the word that is now before the cursor.
* Returns TRUE if the work is done and another char to be got from the user.
*/
static int
ins_compl_bs()
@@ -2951,6 +2957,14 @@ ins_compl_bs()
char_u *line;
char_u *p;
+ line = ml_get_curline();
+ p = line + curwin->w_cursor.col;
+ mb_ptr_back(line, p);
+
+ /* Stop completion when the whole word was deleted. */
+ if ((int)(p - line) - (int)compl_col <= 0)
+ return K_BS;
+
if (curwin->w_cursor.col <= compl_col + compl_length)
{
/* Deleted more than what was used to find matches, need to look for
@@ -2962,10 +2976,6 @@ ins_compl_bs()
compl_cont_mode = 0;
}
- line = ml_get_curline();
- p = line + curwin->w_cursor.col;
- mb_ptr_back(line, p);
-
vim_free(compl_leader);
compl_leader = vim_strnsave(line + compl_col, (int)(p - line) - compl_col);
if (compl_leader != NULL)
@@ -3006,9 +3016,9 @@ ins_compl_bs()
compl_used_match = FALSE;
compl_enter_selects = FALSE;
- return TRUE;
+ return NUL;
}
- return FALSE;
+ return K_BS;
}
/*
@@ -3255,26 +3265,34 @@ ins_compl_prep(c)
/* Get here when we have finished typing a sequence of ^N and
* ^P or other completion characters in CTRL-X mode. Free up
* memory that was used, and make sure we can redo the insert. */
- if (compl_curr_match != NULL)
+ if (compl_curr_match != NULL || compl_leader != NULL || c == Ctrl_E)
{
char_u *p;
/*
* If any of the original typed text has been changed,
* eg when ignorecase is set, we must add back-spaces to
* the redo buffer. We add as few as necessary to delete
* just the part of the original text that has changed.
*/
- ptr = compl_curr_match->cp_str;
+ if (compl_curr_match != NULL && compl_used_match && c != Ctrl_E)
+ ptr = compl_curr_match->cp_str;
+ else if (compl_leader != NULL)
+ ptr = compl_leader;
+ else
+ ptr = compl_orig_text;
p = compl_orig_text;
- while (*p && *p == *ptr)
- {
- ++p;
- ++ptr;
- }
- for (temp = 0; p[temp]; ++temp)
+ for (temp = 0; p[temp] != NUL && p[temp] == ptr[temp]; ++temp)
+ ;
+#ifdef FEAT_MBYTE
+ if (temp > 0)
+ temp -= (*mb_head_off)(compl_orig_text, p + temp);
+#endif
+ for (p += temp; *p != NUL; mb_ptr_adv(p))
AppendCharToRedobuff(K_BS);
- AppendToRedobuffLit(ptr, -1);
+ AppendToRedobuffLit(ptr + temp, -1);
}
#ifdef FEAT_CINDENT
@@ -3981,6 +3999,7 @@ ins_compl_next(allow_get_expansion, count, insert_match)
int todo = count;
compl_T *found_compl = NULL;
int found_end = FALSE;
+ int advance;
if (compl_leader != NULL
&& (compl_shown_match->cp_flags & ORIGINAL_TEXT) == 0)
@@ -3999,6 +4018,10 @@ ins_compl_next(allow_get_expansion, count, insert_match)
/* Delete old text to be replaced */
ins_compl_delete();
+ /* When finding the longest common text we stick at the original text,
+ * don't let CTRL-N or CTRL-P move to the first match. */
+ advance = count != 1 || !allow_get_expansion || !compl_get_longest;
+
/* Repeat this for when <PageUp> or <PageDown> is typed. But don't wrap
* around. */
while (--todo >= 0)
@@ -4023,15 +4046,19 @@ ins_compl_next(allow_get_expansion, count, insert_match)
}
else
{
- if (compl_shows_dir == BACKWARD)
- --compl_pending;
- else
- ++compl_pending;
+ if (advance)
+ {
+ if (compl_shows_dir == BACKWARD)
+ --compl_pending;
+ else
+ ++compl_pending;
+ }
if (!allow_get_expansion)
return -1;
num_matches = ins_compl_get_exp(&compl_startpos);
- if (compl_pending != 0 && compl_direction == compl_shows_dir)
+ if (compl_pending != 0 && compl_direction == compl_shows_dir
+ && advance)
compl_shown_match = compl_curr_match;
found_end = FALSE;
}
@@ -2943,7 +2948,8 @@ ins_compl_active()
* Delete one character before the cursor and show the subset of the matches
* that match the word that is now before the cursor.
- * Returns TRUE if the work is done and another char to be got from the user.
+ * Returns the character to be used, NUL if the work is done and another char
+ * to be got from the user.
*/
static int
@@ -3255,26 +3265,34 @@ ins_compl_prep(c)
char_u *p;
/*
- * If any of the original typed text has been changed,
- * eg when ignorecase is set, we must add back-spaces to
- * the redo buffer. We add as few as necessary to delete
- * just the part of the original text that has changed.
+ * If any of the original typed text has been changed, eg when
+ * ignorecase is set, we must add back-spaces to the redo
+ * buffer. We add as few as necessary to delete just the part
+ * of the original text that has changed.
+ * When using the longest match, edited the match or used
+ * CTRL-E then don't use the current match.
*/